@@ -31,7 +31,6 @@ modules = [
     "artstation",
     "aryion",
     "audiochan",
-    "batoto",
     "bbc",
     "behance",
     "bellazon",
@@ -110,6 +109,7 @@ modules = [
     "iwara",
     "jschan",
     "kabeuchi",
+    "kaliscan",
     "keenspot",
     "kemono",
     "khinsider",
@@ -181,7 +181,6 @@ modules = [
     "rule34vault",
     "rule34xyz",
     "s3ndpics",
-    "saint",
     "sankaku",
     "sankakucomplex",
     "schalenetwork",
@@ -215,6 +214,7 @@ modules = [
     "tumblr",
     "tumblrgallery",
     "tungsten",
+    "turbo",
     "twibooru",
     "twitter",
     "urlgalleries",
