@@ -42,6 +42,7 @@ CATEGORY_MAP = {
     "batoto"         : "BATO.TO",
     "bbc"            : "BBC",
     "booth"          : "BOOTH",
+    "celebforum"     : "celebforum",
     "cfake"          : "Celebrity Fakes",
     "cien"           : "Ci-en",
     "cohost"         : "cohost!",
@@ -112,6 +113,7 @@ CATEGORY_MAP = {
     "itchio"         : "itch.io",
     "jpgfish"        : "JPG Fish",
     "kabeuchi"       : "かべうち",
+    "kaliscan"       : "KaliScan",
     "mangafire"      : "MangaFire",
     "mangareader"    : "MangaReader",
     "mangataro"      : "MangaTaro",
@@ -199,7 +201,7 @@ CATEGORY_MAP = {
     "tmohentai"      : "TMOHentai",
     "tumblrgallery"  : "TumblrGallery",
     "turboimagehost" : "TurboImageHost.com",
-    "turbovid"       : "turbovid.cr",
+    "turbo"          : "turbo.cr",
     "vanillarock"    : "もえぴりあ",
     "vidyart2"       : "/v/idyart2",
     "vidyapics"      : "Vidya Booru",
@@ -474,6 +476,7 @@ SUBCATEGORY_MAP = {
         "media-user": "User Media",
         "media-item": "Media Files",
         "media-category": "Media Categories",
+        "media-album"   : "Albums",
     },
 }
 
@@ -708,11 +711,6 @@ def build_extractor_list():
     default["wikifeetx"] = default["wikifeet"]
     domains["wikifeetx"] = "https://www.wikifeetx.com/"
 
-    # turbovid
-    default["turbovid"] = default["saint"]
-    domains["turbovid"] = "https://turbovid.cr/"
-    domains["saint"] = "https://saint2.su/"
-
     # imgdrive / imgtaxi / imgwallet
     base = categories["imagehost"]
     base["imgtaxi"] = base["imgdrive"]
