@@ -73,6 +73,21 @@ __tests__ = (
     "description": "<a href=\"https://twitter.com/2525_25_25_25_\"><img src=\"https://i.imgur.com/dQCXZkU.png\" alt=\"twitter\"/>Artist's Twitter</a>\r\n<a href=\"https://www.pixiv.net/en/users/67164428\"><img src=\"https://i.imgur.com/oiVINmy.png\" alt=\"pixiv\"/>Artist's Pixiv</a>",
 },
 
+{
+    "#url"     : "https://danke.moe/read/series/awana-chan-wa-kyou-mo-shiawase/2/1/",
+    "#class"   : dankefuerslesen.DankefuerslesenChapterExtractor,
+},
+
+{
+    "#url"     : "https://danke.moe/reader/manga/awana-chan-wa-kyou-mo-shiawase/2/1/",
+    "#class"   : dankefuerslesen.DankefuerslesenChapterExtractor,
+},
+
+{
+    "#url"     : "https://danke.moe/reader/series/awana-chan-wa-kyou-mo-shiawase/2/1/",
+    "#class"   : dankefuerslesen.DankefuerslesenChapterExtractor,
+},
+
 {
     "#url"     : "https://danke.moe/read/manga/awana-chan-wa-kyou-mo-shiawase/",
     "#class"   : dankefuerslesen.DankefuerslesenMangaExtractor,
@@ -90,4 +105,19 @@ __tests__ = (
     "language": None,
 },
 
+{
+    "#url"     : "https://danke.moe/read/series/awana-chan-wa-kyou-mo-shiawase",
+    "#class"   : dankefuerslesen.DankefuerslesenMangaExtractor,
+},
+
+{
+    "#url"     : "https://danke.moe/reader/manga/awana-chan-wa-kyou-mo-shiawase",
+    "#class"   : dankefuerslesen.DankefuerslesenMangaExtractor,
+},
+
+{
+    "#url"     : "https://danke.moe/reader/series/awana-chan-wa-kyou-mo-shiawase",
+    "#class"   : dankefuerslesen.DankefuerslesenMangaExtractor,
+},
+
 )
